<?php

namespace Litecms\Productt\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Productt\Http\Requests\ProducttRequest;
use Litecms\Productt\Interfaces\ProducttRepositoryInterface;
use Litecms\Productt\Models\Productt;

/**
 * Resource controller class for productt.
 */
class ProducttResourceController extends BaseController
{

    /**
     * Initialize productt resource controller.
     *
     * @param type ProducttRepositoryInterface $productt
     *
     * @return null
     */
    public function __construct(ProducttRepositoryInterface $productt)
    {
        parent::__construct();
        $this->repository = $productt;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Productt\Repositories\Criteria\ProducttResourceCriteria::class);
    }

    /**
     * Display a list of productt.
     *
     * @return Response
     */
    public function index(ProducttRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Productt\Repositories\Presenter\ProducttPresenter::class)
                ->$function();
        }

        $productts = $this->repository->paginate();

        return $this->response->title(trans('productt::productt.names'))
            ->view('productt::productt.index', true)
            ->data(compact('productts'))
            ->output();
    }

    /**
     * Display productt.
     *
     * @param Request $request
     * @param Model   $productt
     *
     * @return Response
     */
    public function show(ProducttRequest $request, Productt $productt)
    {

        if ($productt->exists) {
            $view = 'productt::productt.show';
        } else {
            $view = 'productt::productt.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('productt::productt.name'))
            ->data(compact('productt'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new productt.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProducttRequest $request)
    {

        $productt = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('productt::productt.name')) 
            ->view('productt::productt.create', true) 
            ->data(compact('productt'))
            ->output();
    }

    /**
     * Create new productt.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProducttRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $productt                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('productt::productt.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('productt/productt/' . $productt->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/productt/productt'))
                ->redirect();
        }

    }

    /**
     * Show productt for editing.
     *
     * @param Request $request
     * @param Model   $productt
     *
     * @return Response
     */
    public function edit(ProducttRequest $request, Productt $productt)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('productt::productt.name'))
            ->view('productt::productt.edit', true)
            ->data(compact('productt'))
            ->output();
    }

    /**
     * Update the productt.
     *
     * @param Request $request
     * @param Model   $productt
     *
     * @return Response
     */
    public function update(ProducttRequest $request, Productt $productt)
    {
        try {
            $attributes = $request->all();

            $productt->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('productt::productt.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('productt/productt/' . $productt->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('productt/productt/' . $productt->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the productt.
     *
     * @param Model   $productt
     *
     * @return Response
     */
    public function destroy(ProducttRequest $request, Productt $productt)
    {
        try {

            $productt->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('productt::productt.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('productt/productt/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('productt/productt/' . $productt->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple productt.
     *
     * @param Model   $productt
     *
     * @return Response
     */
    public function delete(ProducttRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('productt::productt.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('productt/productt'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/productt/productt'))
                ->redirect();
        }

    }

    /**
     * Restore deleted productts.
     *
     * @param Model   $productt
     *
     * @return Response
     */
    public function restore(ProducttRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('productt::productt.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/productt/productt'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/productt/productt/'))
                ->redirect();
        }

    }

}
